==> haskell-openssl-streams-1.2.3.0-229-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-2OirlWBEDF6AkBAegQAobV
key:                  openssl-streams-1.2.3.0-2OirlWBEDF6AkBAegQAobV
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  0a880b654a507df8b03778accf3f9882
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-2OirlWBEDF6AkBAegQAobV
depends:
    HsOpenSSL-0.11.7.9-PptsFfDVCuG9RAhEnh5qi base-4.16.4.0
    bytestring-0.11.4.0 io-streams-1.5.2.2-GOctHVyl5zA2PM884JGDoB
    network-3.1.4.0-3UsgZVPxzJR3pZOZAOsXvy

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.3.0-230-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openssl-streams
version:              1.2.3.0
visibility:           public
id:                   openssl-streams-1.2.3.0-29HvI9cv96D3IXrFfOM8kq
key:                  openssl-streams-1.2.3.0-29HvI9cv96D3IXrFfOM8kq
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  af5a308e52ac28cc2e435bb9653a1e5b
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-9.2.8/site-local/openssl-streams-1.2.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/openssl-streams-1.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openssl-streams
hs-libraries:         HSopenssl-streams-1.2.3.0-29HvI9cv96D3IXrFfOM8kq
depends:
    HsOpenSSL-0.11.7.9-7fNKn5mliMI47tAp0Vn4HX base-4.16.4.0
    bytestring-0.11.4.0 io-streams-1.5.2.2-27mevNN08NvBjfoThwSYvA
    network-3.1.4.0-TqaTt7QDPb46Ee5sVM3ZA

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
